@@ -8,7 +8,7 @@
  *               based on DMetadata. This interface is used in all cases
  *               where no database is available (aka Showfoto).
  *
- * SPDX-FileCopyrightText: 2017-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2017-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2019-2020 by Minh Nghia Duong <minhnghiaduong997 at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -31,7 +31,9 @@ class DIGIKAM_EXPORT DMetaInfoIface : public DInfoInterface
 
 public:
 
-    explicit DMetaInfoIface(QObject* const, const QList<QUrl>&);
+    explicit DMetaInfoIface(QObject* const parent,
+                            const QList<QUrl>& lst,
+                            const QUrl& currentActive);
     ~DMetaInfoIface()                                             override;
 
     Q_SLOT void slotDateTimeForUrl(const QUrl& url,
@@ -46,6 +48,7 @@ public:
 
     QList<QUrl> currentSelectedItems()                      const override;
     QList<QUrl> currentAlbumItems()                         const override;
+    QUrl        currentActiveItem()                         const override;
     QList<QUrl> allAlbumItems()                             const override;
     void        parseAlbumItemsRecursive()                        override;
 
